@@ -1,5 +1,4 @@
 import numpy as np
-from tqdm import tqdm
 
 import torch
 import torch.nn.functional as F
@@ -11,6 +10,7 @@ from mushroom_rl.utils.torch import to_float_tensor, update_optimizer_parameters
 from mushroom_rl.utils.minibatches import minibatch_generator
 from mushroom_rl.utils.dataset import parse_dataset, compute_J
 from mushroom_rl.utils.value_functions import compute_gae
+from mushroom_rl.utils.parameters import to_parameter
 
 
 class PPO(Agent):
@@ -21,7 +21,7 @@ class PPO(Agent):
 
     """
     def __init__(self, mdp_info, policy, actor_optimizer, critic_params,
-                 n_epochs_policy, batch_size, eps_ppo, lam, quiet=True,
+                 n_epochs_policy, batch_size, eps_ppo, lam,
                  critic_fit_params=None):
         """
         Constructor.
@@ -32,50 +32,43 @@ class PPO(Agent):
                 algorithm;
             critic_params (dict): parameters of the critic approximator to
                 build;
-            n_epochs_policy (int): number of policy updates for every dataset;
-            batch_size (int): size of minibatches for every optimization step
-            eps_ppo (float): value for probability ratio clipping;
-            lam float(float, 1.): lambda coefficient used by generalized
+            n_epochs_policy ((int, Parameter)): number of policy updates for every dataset;
+            batch_size ((int, Parameter)): size of minibatches for every optimization step
+            eps_ppo ((float, Parameter)): value for probability ratio clipping;
+            lam ((float, Parameter), 1.): lambda coefficient used by generalized
                 advantage estimation;
-            quiet (bool, True): if true, the algorithm will print debug
-                information;
             critic_fit_params (dict, None): parameters of the fitting algorithm
                 of the critic approximator.
 
         """
         self._critic_fit_params = dict(n_epochs=10) if critic_fit_params is None else critic_fit_params
 
-        self._n_epochs_policy = n_epochs_policy
-        self._batch_size = batch_size
-        self._eps_ppo = eps_ppo
+        self._n_epochs_policy = to_parameter(n_epochs_policy)
+        self._batch_size = to_parameter(batch_size)
+        self._eps_ppo = to_parameter(eps_ppo)
 
         self._optimizer = actor_optimizer['class'](policy.parameters(), **actor_optimizer['params'])
 
-        self._lambda = lam
+        self._lambda = to_parameter(lam)
 
         self._V = Regressor(TorchApproximator, **critic_params)
 
-        self._quiet = quiet
         self._iter = 1
 
         self._add_save_attr(
             _critic_fit_params='pickle', 
-            _n_epochs_policy='primitive',
-            _batch_size='primitive',
-            _eps_ppo='primitive',
+            _n_epochs_policy='mushroom',
+            _batch_size='mushroom',
+            _eps_ppo='mushroom',
             _optimizer='torch',
-            _lambda='primitive',
+            _lambda='mushroom',
             _V='mushroom',
-            _quiet='primitive',
             _iter='primitive'
         )
 
         super().__init__(mdp_info, policy, None)
 
     def fit(self, dataset):
-        if not self._quiet:
-            tqdm.write('Iteration ' + str(self._iter))
-
         x, u, r, xn, absorbing, last = parse_dataset(dataset)
         x = x.astype(np.float32)
         u = u.astype(np.float32)
@@ -84,7 +77,7 @@ class PPO(Agent):
 
         obs = to_float_tensor(x, self.policy.use_cuda)
         act = to_float_tensor(u, self.policy.use_cuda)
-        v_target, np_adv = compute_gae(self._V, x, xn, r, absorbing, last, self.mdp_info.gamma, self._lambda)
+        v_target, np_adv = compute_gae(self._V, x, xn, r, absorbing, last, self.mdp_info.gamma, self._lambda())
         np_adv = (np_adv - np.mean(np_adv)) / (np.std(np_adv) + 1e-8)
         adv = to_float_tensor(np_adv, self.policy.use_cuda)
 
@@ -96,26 +89,26 @@ class PPO(Agent):
         self._update_policy(obs, act, adv, old_log_p)
 
         # Print fit information
-        self._print_fit_info(dataset, x, v_target, old_pol_dist)
+        self._log_info(dataset, x, v_target, old_pol_dist)
         self._iter += 1
 
     def _update_policy(self, obs, act, adv, old_log_p):
-        for epoch in range(self._n_epochs_policy):
+        for epoch in range(self._n_epochs_policy()):
             for obs_i, act_i, adv_i, old_log_p_i in minibatch_generator(
-                    self._batch_size, obs, act, adv, old_log_p):
+                    self._batch_size(), obs, act, adv, old_log_p):
                 self._optimizer.zero_grad()
                 prob_ratio = torch.exp(
                     self.policy.log_prob_t(obs_i, act_i) - old_log_p_i
                 )
-                clipped_ratio = torch.clamp(prob_ratio, 1 - self._eps_ppo,
-                                            1 + self._eps_ppo)
+                clipped_ratio = torch.clamp(prob_ratio, 1 - self._eps_ppo(),
+                                            1 + self._eps_ppo.get_value())
                 loss = -torch.mean(torch.min(prob_ratio * adv_i,
                                              clipped_ratio * adv_i))
                 loss.backward()
                 self._optimizer.step()
 
-    def _print_fit_info(self, dataset, x, v_target, old_pol_dist):
-        if not self._quiet:
+    def _log_info(self, dataset, x, v_target, old_pol_dist):
+        if self._logger:
             logging_verr = []
             torch_v_targets = torch.tensor(v_target, dtype=torch.float)
             for idx in range(len(self._V)):
@@ -128,10 +121,11 @@ class PPO(Agent):
             logging_kl = torch.mean(torch.distributions.kl.kl_divergence(
                 new_pol_dist, old_pol_dist))
             avg_rwd = np.mean(compute_J(dataset))
-            tqdm.write("Iterations Results:\n\trewards {} vf_loss {}\n\tentropy {}  kl {}".format(
-                avg_rwd, logging_verr, logging_ent, logging_kl))
-            tqdm.write(
-                '--------------------------------------------------------------------------------------------------')
+            msg = "Iteration {}:\n\t\t\t\trewards {} vf_loss {}\n\t\t\t\tentropy {}  kl {}".format(
+                self._iter, avg_rwd, logging_verr, logging_ent, logging_kl)
+
+            self._logger.info(msg)
+            self._logger.weak_line()
 
     def _post_load(self):
         if self._optimizer is not None:
