@@ -22,5 +22,5 @@ class ExpectedSARSA(TD):
         else:
             q_next = 0.
 
-        self.Q[state, action] = q_current + self.alpha(state, action) * (
+        self.Q[state, action] = q_current + self._alpha(state, action) * (
             reward + self.mdp_info.gamma * q_next - q_current)
