@@ -3,7 +3,7 @@ from scipy.optimize import brentq
 from scipy.special import logsumexp
 from .policy import Policy
 
-from mushroom_rl.utils.parameters import Parameter
+from mushroom_rl.utils.parameters import Parameter, to_parameter
 
 
 class TDPolicy(Policy):
@@ -44,17 +44,16 @@ class EpsGreedy(TDPolicy):
         Constructor.
 
         Args:
-            epsilon (Parameter): the exploration coefficient. It indicates
+            epsilon ((float, Parameter)): the exploration coefficient. It indicates
                 the probability of performing a random actions in the current
                 step.
 
         """
         super().__init__()
 
-        assert isinstance(epsilon, Parameter)
-        self._epsilon = epsilon
+        self._epsilon = to_parameter(epsilon)
 
-        self._add_save_attr(_epsilon='pickle')
+        self._add_save_attr(_epsilon='mushroom')
 
     def __call__(self, *args):
         state = args[0]
@@ -92,13 +91,11 @@ class EpsGreedy(TDPolicy):
         Setter.
 
         Args:
-            epsilon (Parameter): the exploration coefficient. It indicates the
+            epsilon ((float, Parameter)): the exploration coefficient. It indicates the
             probability of performing a random actions in the current step.
 
         """
-        assert isinstance(epsilon, Parameter)
-
-        self._epsilon = epsilon
+        self._epsilon = to_parameter(epsilon)
 
     def update(self, *idx):
         """
@@ -123,16 +120,16 @@ class Boltzmann(TDPolicy):
         Constructor.
 
         Args:
-            beta (Parameter): the inverse of the temperature distribution. As
+            beta ((float, Parameter)): the inverse of the temperature distribution. As
             the temperature approaches infinity, the policy becomes more and
             more random. As the temperature approaches 0.0, the policy becomes
             more and more greedy.
 
         """
         super().__init__()
-        self._beta = beta
+        self._beta = to_parameter(beta)
 
-        self._add_save_attr(_beta='pickle')
+        self._add_save_attr(_beta='mushroom')
 
     def __call__(self, *args):
         state = args[0]
@@ -156,12 +153,10 @@ class Boltzmann(TDPolicy):
         Setter.
 
         Args:
-            beta (Parameter): the inverse of the temperature distribution.
+            beta ((float, Parameter)): the inverse of the temperature distribution.
 
         """
-        assert isinstance(beta, Parameter)
-
-        self._beta = beta
+        self._beta = to_parameter(beta)
 
     def update(self, *idx):
         """
@@ -184,13 +179,20 @@ class Mellowmax(Boltzmann):
 
     """
 
-    class MellowmaxParameter:
+    class MellowmaxParameter(Parameter):
         def __init__(self, outer, omega, beta_min, beta_max):
             self._omega = omega
             self._outer = outer
             self._beta_min = beta_min
             self._beta_max = beta_max
 
+            self._add_save_attr(
+                _omega='primitive',
+                _outer='primitive',
+                _beta_min='primitive',
+                _beta_max='primitive',
+            )
+
         def __call__(self, state):
             q = self._outer._approximator.predict(state)
             mm = (logsumexp(q * self._omega(state)) - np.log(
@@ -232,4 +234,4 @@ class Mellowmax(Boltzmann):
         raise RuntimeError('Cannot change the beta parameter of Mellowmax policy')
 
     def update(self, *idx):
-        raise RuntimeError('Cannot update the beta parameter of Mellowmax policy')
\ No newline at end of file
+        raise RuntimeError('Cannot update the beta parameter of Mellowmax policy')
