@@ -7,6 +7,7 @@ from mushroom_rl.policy import Policy
 from mushroom_rl.approximators import Regressor
 from mushroom_rl.approximators.parametric import TorchApproximator
 from mushroom_rl.utils.torch import to_float_tensor
+from mushroom_rl.utils.parameters import to_parameter
 
 from itertools import chain
 
@@ -265,7 +266,7 @@ class BoltzmannTorchPolicy(TorchPolicy):
                 regressor;
             input_shape (tuple): the shape of the state space;
             output_shape (tuple): the shape of the action space;
-            beta (Parameter): the inverse of the temperature distribution. As
+            beta ((float, Parameter)): the inverse of the temperature distribution. As
                 the temperature approaches infinity, the policy becomes more and
                 more random. As the temperature approaches 0.0, the policy becomes
                 more and more greedy.
@@ -278,17 +279,17 @@ class BoltzmannTorchPolicy(TorchPolicy):
 
         self._logits = Regressor(TorchApproximator, input_shape, output_shape,
                                  network=network, use_cuda=use_cuda, **params)
-        self._beta = beta
+        self._beta = to_parameter(beta)
 
         self._add_save_attr(
             _action_dim='primitive',
-            _beta='pickle',
+            _beta='mushroom',
             _logits='mushroom'
         )
 
     def draw_action_t(self, state):
         action = self.distribution_t(state).sample().detach()
-        #print(action)
+
         if len(action.shape) > 1:
             return action
         else:
@@ -311,4 +312,7 @@ class BoltzmannTorchPolicy(TorchPolicy):
         return self._logits.get_weights()
 
     def parameters(self):
-        return self._logits.model.network.parameters()
\ No newline at end of file
+        return self._logits.model.network.parameters()
+
+    def set_beta(self, beta):
+        self._beta = to_parameter(beta)
